@@ -10,6 +10,6 @@ role PDF::Action::GoTo
     # see [PDF 1.7 TABLE 8.49 Additional entries specific to a go-to action]
     use PDF::DAO::Tie;
 
-    has $.D is entry(:required);    #| (Required) The destination to jump to (see Section 8.2.1, “Destinations”).
+    has $.D is entry(:required, :alias<destination>);    #| (Required) The destination to jump to (see Section 8.2.1, “Destinations”).
 
 }
