@@ -7,10 +7,11 @@ class PDF::ColorSpace::Separation
 
     use PDF::DAO::Tie;
     use PDF::DAO::Name;
-    # see [PDF 1.7 Section 4.5.5 Special Color Spaces] 
+    use PDF::Function;
+    # see [PDF 1.7 Section 4.5.5 Special Color Spaces]
     has PDF::DAO::Name $.Name is index(1);
     subset ArrayOrName where Array | PDF::DAO::Name;
     has ArrayOrName $.AlternateSpace is index(2);
-    has $.TintTransform is index(3);
+    has PDF::Function $.TintTransform is index(3);
 
 }
