@@ -7,7 +7,7 @@ use PDF::Content::XObject;
 #| See [PDF 1.7 Section 4.7.1 PostScript XObjects]
 class PDF::XObject::PS
     is PDF::XObject
-    does PDF::Content::XObject[PS] {
+    does PDF::Content::XObject['PS'] {
 
     use PDF::DAO::Tie;
     use PDF::DAO::Stream;
